.. title:: Documentation of yet_another_wizz


.. grid::
    :gutter: 2 3 4 4
    :margin: 0 auto auto auto
    :padding: 0

    .. grid-item-card::
        :columns: 12
        :class-body: lead
        :img-top: /_static/title.svg

        `yet_another_wizz` is an open source python package to efficiently
        compute cross-correlation redshifts, also known as clustering redshifts.

    .. grid-item::
        :columns: 12

        .. dropdown:: :octicon:`list-ordered;1.5em` ‎ ‎ ‎ Expand table of contents
            :margin: 0
            :color: muted
            :class-title: h5

            .. toctree::
                :maxdepth: 2

                user_guide
                api
                changes

    .. grid-item-card:: The new one
        :columns: 6
        :link: starting
        :link-type: ref
        :text-align: center

        :octicon:`milestone;3em`

        Getting started

    .. grid-item-card:: The impatient
        :columns: 6
        :link: theexample
        :link-type: ref
        :text-align: center

        :octicon:`rocket;3em`

        Usage example

    .. grid-item-card:: The thorough
        :columns: 6
        :link: guide
        :link-type: ref
        :text-align: center

        :octicon:`book;3em`

        User guide

    .. grid-item-card:: The detail oriented
        :columns: 6
        :link: api
        :link-type: ref
        :text-align: center

        :octicon:`codescan;3em`

        API reference
